==> RSTouchscreenNG-1.4.11.zip: RSTouchscreenNG/projects/pages/src/lib/networks.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {ConnectionHandler, RepetierState, ServerEvent, WifiState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-networks",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *ngIf="(wifi$ | async).manageable" title="<?php _('WLAN') ?>" icon="fa fa-rss" link="/wlan"></rs-sideicon>
        <rs-empty-sideicon *ngIf="!((wifi$ | async).manageable)"></rs-empty-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon icon="fa fa-gear" title="<?php _('Settings') ?>" link="/settings"></rs-sideicon>
      </rs-side>
      <main>
        <rs-headline class="margin-bottom"><i class="fa fa-sitemap"></i> <?php _('Network Interfaces') ?></rs-headline>
        <div class="content-h1" rsDrag>
          <div style="display:flex;flex-wrap: wrap;justify-content: space-between">
            <div *ngFor="let n of net.ipv4" style="padding: 10px; margin:0 auto;">
              <h2>{{n.name}}</h2>
              <div style="text-align: center;margin:8px">
                <p>
                  {{connectionHandler.httpType}}://{{n.ip}}:{{net.port}}<br>
                  MAC: {{n.mac}}
                </p>
                <rs-qrcode [ip]="n.ip" [port]="net.port" margin="2" modSize="5"></rs-qrcode>
              </div>
            </div>
          </div>
        </div>
      </main>
    </rs-page>
  `
})

export class NetworksComponent implements OnDestroy {
  wifi$: Observable<WifiState>;
  net: any = {ipv4: []};
  private connectionSubscription: SubscriptionLike;

  constructor(public connectionHandler: ConnectionHandler,
              private store: Store<RepetierState>) {
    this.wifi$ = store.select("wifi");
    this.connectionSubscription = connectionHandler.connectionState.subscribe(on => {
      if (on) {
        this.updateInterfaces();
      }
    });
  }

  private localEventHandler = (evt: ServerEvent) => {
    switch (evt.event) {
      case "connected":
        this.updateInterfaces();
        break;
    }
  };

  updateInterfaces() {
    this.connectionHandler.networkInterfaces().then((data) => {
      this.net = data;
    }, () => {
    });
  }

  ngOnDestroy() {
    this.connectionSubscription.unsubscribe();
  }

  protected readonly undefined = undefined;
}

==> RSTouchscreenNG-1.4.16.zip: RSTouchscreenNG/projects/pages/src/lib/networks.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {ConnectionHandler, RepetierState, ServerEvent, ServerState, WifiState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-networks",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon *ngIf="(wifi$ | async).manageable && (server$|async).features['config-network']" title="<?php _('WLAN') ?>" icon="fa fa-rss" link="/wlan"></rs-sideicon>
        <rs-empty-sideicon *ngIf="!((wifi$ | async).manageable)"></rs-empty-sideicon>
      </rs-side>
      <rs-side>
        <rs-sideicon icon="fa fa-gear" title="<?php _('Settings') ?>" link="/settings"></rs-sideicon>
      </rs-side>
      <main>
        <rs-headline class="margin-bottom"><i class="fa fa-sitemap"></i> <?php _('Network Interfaces') ?></rs-headline>
        <div class="content-h1" rsDrag>
          <div>
            <div style="display:flex;flex-wrap: wrap;justify-content: space-between">
              <div *ngFor="let n of net.ipv4" style="padding: 10px; margin:0 auto;">
                <h2>{{ n.name }}</h2>
                <div style="text-align: center;margin:8px">
                  <p>
                    {{ connectionHandler.httpType }}://{{ n.ip }}:{{ net.port }}<br>
                    MAC: {{ n.mac }}
                  </p>
                  <rs-qrcode [ip]="n.ip" [port]="net.port" margin="2" modSize="5"></rs-qrcode>
                </div>
              </div>
            </div>
          </div>
        </div>
      </main>
    </rs-page>
  `
})

export class NetworksComponent implements OnDestroy {
  wifi$: Observable<WifiState>;
  server$: Observable<ServerState>;
  net: any = {ipv4: []};
  private connectionSubscription: SubscriptionLike;

  constructor(public connectionHandler: ConnectionHandler,
              private store: Store<RepetierState>) {
    this.wifi$ = store.select("wifi");
    this.server$ = store.select("server");
    this.connectionSubscription = connectionHandler.connectionState.subscribe(on => {
      if (on) {
        this.updateInterfaces();
      }
    });
  }

  private localEventHandler = (evt: ServerEvent) => {
    switch (evt.event) {
      case "connected":
        this.updateInterfaces();
        break;
    }
  };

  updateInterfaces() {
    this.connectionHandler.networkInterfaces().then((data) => {
      this.net = data;
    }, () => {
    });
  }

  ngOnDestroy() {
    this.connectionSubscription.unsubscribe();
  }

  protected readonly undefined = undefined;
}
